@@ -2,7 +2,7 @@ import typer
 import socket
 import json
 import pyperclip
-import time
+import time as timer
 from time import time
 import os
 from tabulate import tabulate
@@ -144,7 +144,7 @@ def list(search: str = typer.Argument("")):
         pyperclip.copy(response.decode("utf-8"))
         typer.secho(str(response.decode('utf-8')), fg=typer.colors.BLUE, bold=True)
     elif task['outputType'] == 2:
-        time_str = time.strftime("%Y-%m-%d-%H_%M_%S")
+        time_str = timer.strftime("%Y-%m-%d-%H_%M_%S")
         file_name = downloads_path + time_str + ".json"
 
         f = open(file_name, 'w')
